diff -ur ooo_SRC680_m144_src.orig/binfilter/bf_forms/source/component/forms_imgprod.cxx ooo_SRC680_m144_src/binfilter/bf_forms/source/component/forms_imgprod.cxx
--- ooo_SRC680_m144_src.orig/binfilter/bf_forms/source/component/forms_imgprod.cxx	2005-12-08 11:52:35.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/bf_forms/source/component/forms_imgprod.cxx	2005-12-08 11:57:07.000000000 +0100
@@ -70,8 +70,8 @@
 						ImgProdLockBytes( ::com::sun::star::uno::Reference< ::com::sun::star::io::XInputStream > & rStreamRef );
 	virtual				~ImgProdLockBytes();
 
-	virtual ErrCode		ReadAt( sal_uInt32 nPos, void* pBuffer, sal_uInt32 nCount, sal_uInt32* pRead ) const;
-	virtual ErrCode		WriteAt( sal_uInt32 nPos, const void* pBuffer, sal_uInt32 nCount, sal_uInt32* pWritten );
+	virtual ErrCode		ReadAt( sal_uInt32 nPos, void* pBuffer, sal_Size nCount, sal_Size* pRead ) const;
+	virtual ErrCode		WriteAt( sal_uInt32 nPos, const void* pBuffer, sal_Size nCount, sal_Size* pWritten );
 	virtual ErrCode		Flush() const;
 	virtual ErrCode		SetSize( sal_uInt32 nSize );
 	virtual ErrCode		Stat( SvLockBytesStat*, SvLockBytesStatFlag ) const;
@@ -119,7 +119,7 @@
 
 // ------------------------------------------------------------------------
 
-ErrCode ImgProdLockBytes::ReadAt( sal_uInt32 nPos, void* pBuffer, sal_uInt32 nCount, sal_uInt32* pRead ) const
+ErrCode ImgProdLockBytes::ReadAt( sal_uInt32 nPos, void* pBuffer, sal_Size nCount, sal_Size* pRead ) const
 {
 	if( GetStream() )
 	{
@@ -150,7 +150,7 @@
 
 // ------------------------------------------------------------------------
 
-ErrCode ImgProdLockBytes::WriteAt( sal_uInt32 nPos, const void* pBuffer, sal_uInt32 nCount, sal_uInt32* pWritten )
+ErrCode ImgProdLockBytes::WriteAt( sal_uInt32 nPos, const void* pBuffer, sal_Size nCount, sal_Size* pWritten )
 {
 	if( GetStream() )
 		return SvLockBytes::WriteAt( nPos, pBuffer, nCount, pWritten );
diff -ur ooo_SRC680_m144_src.orig/binfilter/bf_sc/source/core/data/sc_column3.cxx ooo_SRC680_m144_src/binfilter/bf_sc/source/core/data/sc_column3.cxx
--- ooo_SRC680_m144_src.orig/binfilter/bf_sc/source/core/data/sc_column3.cxx	2005-12-08 11:52:35.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/bf_sc/source/core/data/sc_column3.cxx	2005-12-08 13:05:34.000000000 +0100
@@ -1212,7 +1212,7 @@
 /*N*/ 		if (rString.Len() > 0)
 /*N*/ 		{
 /*N*/ 			double nVal;
-/*N*/ 			ULONG nIndex, nOldIndex;
+/*N*/ 			sal_uInt32 nIndex, nOldIndex;
 /*N*/ 			sal_Unicode cFirstChar;
 /*N*/ 			SvNumberFormatter* pFormatter = pDocument->GetFormatTable();
 /*N*/ 			SfxObjectShell* pDocSh = pDocument->GetDocumentShell();
diff -ur ooo_SRC680_m144_src.orig/binfilter/bf_sc/source/core/data/sc_dociter.cxx ooo_SRC680_m144_src/binfilter/bf_sc/source/core/data/sc_dociter.cxx
--- ooo_SRC680_m144_src.orig/binfilter/bf_sc/source/core/data/sc_dociter.cxx	2005-12-08 11:52:35.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/bf_sc/source/core/data/sc_dociter.cxx	2005-12-08 13:07:07.000000000 +0100
@@ -508,7 +508,7 @@
 /*N*/  	for (i=0; (i<nCount) && (aParam.GetEntry(i).bDoQuery); i++)
 /*N*/  	{
 /*N*/  		ScQueryEntry& rEntry = aParam.GetEntry(i);
-/*N*/  		ULONG nIndex = 0;
+/*N*/  		sal_uInt32 nIndex = 0;
 /*N*/  		rEntry.bQueryByString =
 /*N*/  				!(pDoc->GetFormatTable()->IsNumberFormat(*rEntry.pStr, nIndex, rEntry.nVal));
 /*N*/  	}
@@ -794,7 +794,7 @@
 /*N*/ 		for (i=0; (i<MAXQUERY) && (aParam.GetEntry(i).bDoQuery); i++)
 /*N*/ 		{
 /*?*/ 			ScQueryEntry& rEntry = aParam.GetEntry(i);
-/*?*/ 			ULONG nIndex = 0;
+/*?*/ 			sal_uInt32 nIndex = 0;
 /*?*/ 			rEntry.bQueryByString =
 /*?*/ 					 !(pDoc->GetFormatTable()->IsNumberFormat(*rEntry.pStr,
 /*?*/ 															  nIndex, rEntry.nVal));
diff -ur ooo_SRC680_m144_src.orig/binfilter/bf_sc/source/core/data/sc_document.cxx ooo_SRC680_m144_src/binfilter/bf_sc/source/core/data/sc_document.cxx
--- ooo_SRC680_m144_src.orig/binfilter/bf_sc/source/core/data/sc_document.cxx	2005-12-08 11:52:35.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/bf_sc/source/core/data/sc_document.cxx	2005-12-08 14:12:51.000000000 +0100
@@ -2025,7 +2025,7 @@
 
 
 /*N*/ void ScDocument::GetNumberFormat( USHORT nCol, USHORT nRow, USHORT nTab,
-/*N*/ 								  ULONG& rFormat )
+/*N*/ 								  sal_uInt32& rFormat )
 /*N*/ {
 /*N*/ 	if (VALIDTAB(nTab))
 /*N*/ 		if (pTab[nTab])
@@ -2037,7 +2037,7 @@
 /*N*/ }
 
 
-/*N*/ ULONG ScDocument::GetNumberFormat( const ScAddress& rPos ) const
+/*N*/ sal_uInt32 ScDocument::GetNumberFormat( const ScAddress& rPos ) const
 /*N*/ {
 /*N*/ 	USHORT nTab = rPos.Tab();
 /*N*/ 	if ( pTab[nTab] )
diff -ur ooo_SRC680_m144_src.orig/binfilter/bf_sc/source/core/data/sc_dpshttab.cxx ooo_SRC680_m144_src/binfilter/bf_sc/source/core/data/sc_dpshttab.cxx
--- ooo_SRC680_m144_src.orig/binfilter/bf_sc/source/core/data/sc_dpshttab.cxx	2005-12-08 11:52:35.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/bf_sc/source/core/data/sc_dpshttab.cxx	2005-12-08 13:08:55.000000000 +0100
@@ -105,7 +105,7 @@
 /*M*/             }
 /*M*/             else
 /*M*/             {
-/*M*/ 		        ULONG nIndex = 0;
+/*M*/ 		        sal_uInt32 nIndex = 0;
 /*M*/ 		        rEntry.bQueryByString =
 /*M*/ 					        !(pD->GetFormatTable()->
 /*M*/ 						        IsNumberFormat(*rEntry.pStr, nIndex, rEntry.nVal));
diff -ur ooo_SRC680_m144_src.orig/binfilter/bf_sc/source/core/data/sc_table3.cxx ooo_SRC680_m144_src/binfilter/bf_sc/source/core/data/sc_table3.cxx
--- ooo_SRC680_m144_src.orig/binfilter/bf_sc/source/core/data/sc_table3.cxx	2005-12-08 11:52:35.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/bf_sc/source/core/data/sc_table3.cxx	2005-12-08 13:12:02.000000000 +0100
@@ -1050,7 +1050,7 @@
 /*N*/                         bOk = pTransliteration->isEqual( aCellStr, *rEntry.pStr );
 /*N*/ 					else
 /*N*/ 					{
-/*N*/                         ::com::sun::star::uno::Sequence< long > xOff;
+/*N*/                         ::com::sun::star::uno::Sequence< sal_Int32 > xOff;
 /*N*/                         String aCell( pTransliteration->transliterate(
 /*N*/                             aCellStr, ScGlobal::eLnge, 0, aCellStr.Len(),
 /*N*/                             &xOff ) );
diff -ur ooo_SRC680_m144_src.orig/binfilter/bf_sc/source/core/tool/sc_chartarr.cxx ooo_SRC680_m144_src/binfilter/bf_sc/source/core/tool/sc_chartarr.cxx
--- ooo_SRC680_m144_src.orig/binfilter/bf_sc/source/core/tool/sc_chartarr.cxx	2005-12-08 11:52:35.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/bf_sc/source/core/tool/sc_chartarr.cxx	2005-12-08 14:17:52.000000000 +0100
@@ -68,14 +68,14 @@
 /*N*/ 	rDest.SetYAxisTitle( rSource.GetYAxisTitle() );
 /*N*/ 	rDest.SetZAxisTitle( rSource.GetZAxisTitle() );
 /*N*/ 
-/*N*/ 	const long* pArr;
+/*N*/ 	sal_Int32* pArr;
 /*N*/ 	if ( rSource.GetRowCount() == rDest.GetRowCount() &&
 /*N*/ 		 rSource.GetColCount() == rDest.GetColCount() )
 /*N*/ 	{
 /*N*/ 		//	don't copy column/row number formats here (are set in new MemChart object)
 /*N*/ 
-/*N*/ 		if ( (pArr = rSource.GetRowTranslation()) ) rDest.SetRowTranslation( pArr );
-/*N*/ 		if ( (pArr = rSource.GetColTranslation()) ) rDest.SetColTranslation( pArr );
+/*N*/ 		if ( (pArr = (sal_Int32 *) rSource.GetRowTranslation()) ) rDest.SetRowTranslation( pArr );
+/*N*/ 		if ( (pArr = (sal_Int32 *) rSource.GetColTranslation()) ) rDest.SetColTranslation( pArr );
 /*N*/ 		rDest.SetTranslation( rSource.GetTranslation() );
 /*N*/ 	}
 /*N*/ }
@@ -698,7 +698,7 @@
 /*?*/ 							nVal = ((ScValueCell*)pCell)->GetValue();
 /*?*/ 							if ( bCalcAsShown && nVal != 0.0 )
 /*?*/ 							{
-/*?*/ 								ULONG nFormat;
+/*?*/ 								sal_uInt32 nFormat;
 /*?*/ 								pDocument->GetNumberFormat( pCols[nCol],
 /*?*/ 									pRows[nRow], nTab1, nFormat );
 /*?*/ 								nVal = pDocument->RoundValueAsShown( nVal, nFormat );
diff -ur ooo_SRC680_m144_src.orig/binfilter/bf_sc/source/core/tool/sc_compiler.cxx ooo_SRC680_m144_src/binfilter/bf_sc/source/core/tool/sc_compiler.cxx
--- ooo_SRC680_m144_src.orig/binfilter/bf_sc/source/core/tool/sc_compiler.cxx	2005-12-08 11:52:35.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/bf_sc/source/core/tool/sc_compiler.cxx	2005-12-08 13:20:00.000000000 +0100
@@ -877,7 +877,7 @@
 /*N*/ BOOL ScCompiler::IsValue( const String& rSym )
 /*N*/ {
 /*N*/ 	double fVal;
-/*N*/ 	ULONG nIndex = ( pSymbolTable == pSymbolTableEnglish ?
+/*N*/ 	sal_uInt32 nIndex = ( pSymbolTable == pSymbolTableEnglish ?
 /*N*/ 		pDoc->GetFormatTable()->GetStandardIndex( LANGUAGE_ENGLISH_US ) : 0 );
 /*N*/ //	ULONG nIndex = 0;
 /*N*/ ////	ULONG nIndex = pDoc->GetFormatTable()->GetStandardIndex(ScGlobal::eLnge);
diff -ur ooo_SRC680_m144_src.orig/binfilter/bf_sc/source/core/tool/sc_interpr2.cxx ooo_SRC680_m144_src/binfilter/bf_sc/source/core/tool/sc_interpr2.cxx
--- ooo_SRC680_m144_src.orig/binfilter/bf_sc/source/core/tool/sc_interpr2.cxx	2005-12-08 11:52:35.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/bf_sc/source/core/tool/sc_interpr2.cxx	2005-12-08 13:24:17.000000000 +0100
@@ -172,7 +172,7 @@
 void ScInterpreter::ScGetDateValue()
 {
 	String aInputString = GetString();
-	ULONG nFIndex = 0;					// damit default Land/Spr.
+	sal_uInt32 nFIndex = 0;					// damit default Land/Spr.
 	double fVal;
 	if (pFormatter->IsNumberFormat(aInputString, nFIndex, fVal))
 	{
@@ -361,7 +361,7 @@
 void ScInterpreter::ScGetTimeValue()
 {
 	String aInputString = GetString();
-	ULONG nFIndex = 0;					// damit default Land/Spr.
+	sal_uInt32 nFIndex = 0;					// damit default Land/Spr.
 	double fVal;
 	if (pFormatter->IsNumberFormat(aInputString, nFIndex, fVal))
 	{
diff -ur ooo_SRC680_m144_src.orig/binfilter/bf_sc/source/core/tool/sc_interpr4.cxx ooo_SRC680_m144_src/binfilter/bf_sc/source/core/tool/sc_interpr4.cxx
--- ooo_SRC680_m144_src.orig/binfilter/bf_sc/source/core/tool/sc_interpr4.cxx	2005-12-08 11:52:35.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/bf_sc/source/core/tool/sc_interpr4.cxx	2005-12-08 13:24:56.000000000 +0100
@@ -1288,7 +1288,7 @@
 /*N*/ 		case svString:
 /*N*/ 		{
 /*N*/ 			String aStr(PopString());
-/*N*/ 			ULONG nFIndex = 0;					// damit default Land/Spr.
+/*N*/ 			sal_uInt32 nFIndex = 0;					// damit default Land/Spr.
 /*N*/ 			if(!pFormatter->IsNumberFormat( aStr, nFIndex, nVal ) )
 /*N*/ 			{
 /*N*/ 				SetError(errIllegalArgument);
diff -ur ooo_SRC680_m144_src.orig/binfilter/bf_sc/source/ui/app/sc_inputhdl.cxx ooo_SRC680_m144_src/binfilter/bf_sc/source/ui/app/sc_inputhdl.cxx
--- ooo_SRC680_m144_src.orig/binfilter/bf_sc/source/ui/app/sc_inputhdl.cxx	2005-12-08 11:52:35.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/bf_sc/source/ui/app/sc_inputhdl.cxx	2005-12-08 13:27:53.000000000 +0100
@@ -2029,7 +2029,7 @@
 /*?*/ 			ScDocument* pDoc = pActiveViewSh->GetViewData()->GetDocument();
 /*?*/ 			SvNumberFormatter* pFormatter = pDoc->GetFormatTable();
 /*?*/ 			// without conditional format, as in ScColumn::SetString
-/*?*/ 			ULONG nFormat = pLastPattern->GetNumberFormat( pFormatter );
+/*?*/ 			sal_uInt32 nFormat = pLastPattern->GetNumberFormat( pFormatter );
 /*?*/ 			double nVal;
 /*?*/ 			if ( pFormatter->IsNumberFormat( aString, nFormat, nVal ) )
 /*?*/ 			{
diff -ur ooo_SRC680_m144_src.orig/binfilter/bf_sc/source/ui/docshell/sc_docfunc.cxx ooo_SRC680_m144_src/binfilter/bf_sc/source/ui/docshell/sc_docfunc.cxx
--- ooo_SRC680_m144_src.orig/binfilter/bf_sc/source/ui/docshell/sc_docfunc.cxx	2005-12-08 11:52:35.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/bf_sc/source/ui/docshell/sc_docfunc.cxx	2005-12-08 13:32:29.000000000 +0100
@@ -986,7 +986,7 @@
 /*N*/ 	else		// (nur) auf englisches Zahlformat testen
 /*N*/ 	{
 /*?*/ 		SvNumberFormatter* pFormatter = pDoc->GetFormatTable();
-/*?*/ 		ULONG nEnglish = pFormatter->GetStandardIndex(LANGUAGE_ENGLISH_US);
+/*?*/ 		sal_uInt32 nEnglish = pFormatter->GetStandardIndex(LANGUAGE_ENGLISH_US);
 /*?*/ 		double fVal;
 /*?*/ 		if ( pFormatter->IsNumberFormat( rText, nEnglish, fVal ) )
 /*?*/ 			pNewCell = new ScValueCell( fVal );
diff -ur ooo_SRC680_m144_src.orig/binfilter/bf_sc/source/ui/docshell/sc_impex.cxx ooo_SRC680_m144_src/binfilter/bf_sc/source/ui/docshell/sc_impex.cxx
--- ooo_SRC680_m144_src.orig/binfilter/bf_sc/source/ui/docshell/sc_impex.cxx	2005-12-08 11:52:35.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/bf_sc/source/ui/docshell/sc_impex.cxx	2005-12-08 13:33:26.000000000 +0100
@@ -802,7 +802,7 @@
 /*M*/ 		//!	SetString mit Extra-Flag ???
 /*M*/ 
 /*M*/ 		SvNumberFormatter* pFormatter = pDoc->GetFormatTable();
-/*M*/ 		ULONG nEnglish = pFormatter->GetStandardIndex(LANGUAGE_ENGLISH_US);
+/*M*/ 		sal_uInt32 nEnglish = pFormatter->GetStandardIndex(LANGUAGE_ENGLISH_US);
 /*M*/ 		double fVal;
 /*M*/ 		if ( pFormatter->IsNumberFormat( rStr, nEnglish, fVal ) )
 /*M*/ 		{
diff -ur ooo_SRC680_m144_src.orig/binfilter/bf_sc/source/ui/unoobj/sc_cellsuno.cxx ooo_SRC680_m144_src/binfilter/bf_sc/source/ui/unoobj/sc_cellsuno.cxx
--- ooo_SRC680_m144_src.orig/binfilter/bf_sc/source/ui/unoobj/sc_cellsuno.cxx	2005-12-08 11:52:35.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/bf_sc/source/ui/unoobj/sc_cellsuno.cxx	2005-12-08 13:39:25.000000000 +0100
@@ -1319,7 +1319,7 @@
                 // Since the English formatter was constructed with
                 // LANGUAGE_ENGLISH_US the "General" format has index key 0,
                 // we don't have to query.
-				ULONG nNumFmt = bEnglish ?
+				sal_uInt32 nNumFmt = bEnglish ?
 //						pFormatter->GetStandardIndex(LANGUAGE_ENGLISH_US) :
                         0 :
 						pDoc->GetNumberFormat( rPosition );
diff -ur ooo_SRC680_m144_src.orig/binfilter/bf_sc/source/ui/view/sc_tabvwsha.cxx ooo_SRC680_m144_src/binfilter/bf_sc/source/ui/view/sc_tabvwsha.cxx
--- ooo_SRC680_m144_src.orig/binfilter/bf_sc/source/ui/view/sc_tabvwsha.cxx	2005-12-08 11:52:35.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/bf_sc/source/ui/view/sc_tabvwsha.cxx	2005-12-08 14:06:26.000000000 +0100
@@ -110,7 +110,7 @@
 /*N*/ 		aStr += '=';
 /*N*/ 
 /*N*/ 		//	Anzahl im Standardformat, die anderen nach Cursorposition
-/*N*/ 		ULONG nNumFmt = 0;
+/*N*/ 		sal_uInt32 nNumFmt = 0;
 /*N*/ 		SvNumberFormatter* pFormatter = pDoc->GetFormatTable();
 /*N*/ 		if ( eFunc != SUBTOTAL_FUNC_CNT && eFunc != SUBTOTAL_FUNC_CNT2 )
 /*N*/ 		{
@@ -525,7 +525,7 @@
 /*N*/ 					//!	Auch bei Zahlformat "Text"? -> dann beim Editieren wegnehmen
 /*N*/ 
 /*?*/ 					SvNumberFormatter* pFormatter = pDoc->GetFormatTable();
-/*?*/ 					ULONG nNumFmt;
+/*?*/ 					sal_uInt32 nNumFmt;
 /*?*/ 					pDoc->GetNumberFormat( nPosX, nPosY, nTab, nNumFmt );
 /*?*/ 					double fDummy;
 /*?*/ 					if ( pFormatter->IsNumberFormat(aString, nNumFmt, fDummy) )
diff -ur ooo_SRC680_m144_src.orig/binfilter/bf_sch/source/core/sch_chtmode2.cxx ooo_SRC680_m144_src/binfilter/bf_sch/source/core/sch_chtmode2.cxx
--- ooo_SRC680_m144_src.orig/binfilter/bf_sch/source/core/sch_chtmode2.cxx	2005-12-08 11:52:35.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/bf_sch/source/core/sch_chtmode2.cxx	2005-12-08 14:28:58.000000000 +0100
@@ -2169,7 +2169,7 @@
 /*N*/ 			{
 /*N*/ 				BOOL bNeedMerge=FALSE;
 /*N*/ 				String aFmtStr;
-/*N*/ 				ULONG nId;
+/*N*/ 				sal_uInt32 nId;
 /*N*/ 				if(nVersion <= 11)//ab V 12 X=Y=Z-Numberformatter!
 /*N*/ 				{
 /*?*/ 					SvNumberFormatter *pTmp = new SvNumberFormatter( ::legacy_binfilters::getLegacyProcessServiceFactory(),
diff -ur ooo_SRC680_m144_src.orig/binfilter/bf_sd/source/ui/inc/AccessiblePageShape.hxx ooo_SRC680_m144_src/binfilter/bf_sd/source/ui/inc/AccessiblePageShape.hxx
--- ooo_SRC680_m144_src.orig/binfilter/bf_sd/source/ui/inc/AccessiblePageShape.hxx	2005-12-08 11:52:35.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/bf_sd/source/ui/inc/AccessiblePageShape.hxx	2005-12-08 14:36:54.000000000 +0100
@@ -114,7 +114,7 @@
 	//=====  XAccessibleContext  ==============================================
 
     ///	Returns always 0 because there can be no children.
-    virtual long SAL_CALL
+    virtual sal_Int32 SAL_CALL
     	getAccessibleChildCount (void)
         throw ();
         
diff -ur ooo_SRC680_m144_src.orig/binfilter/bf_sd/source/ui/unoidl/sd_unoobj.cxx ooo_SRC680_m144_src/binfilter/bf_sd/source/ui/unoidl/sd_unoobj.cxx
--- ooo_SRC680_m144_src.orig/binfilter/bf_sd/source/ui/unoidl/sd_unoobj.cxx	2005-12-08 11:52:35.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/bf_sd/source/ui/unoidl/sd_unoobj.cxx	2005-12-08 14:35:10.000000000 +0100
@@ -431,7 +431,7 @@
 ::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySetInfo > SAL_CALL SdXShape::getPropertySetInfo()
 	throw(::com::sun::star::uno::RuntimeException)
 {
-	sal_uInt32 nObjId = (sal_uInt32)mpShape->getPropertyMap();
+	sal_uIntPtr nObjId = (sal_uIntPtr)mpShape->getPropertyMap();
 	SfxExtItemPropertySetInfo* pInfo = NULL;
 
 	SdExtPropertySetInfoCache* pCache = (mpModel && mpModel->IsImpressDocument()) ? 
diff -ur ooo_SRC680_m144_src.orig/binfilter/bf_sfx2/source/doc/sfx2_docinf.cxx ooo_SRC680_m144_src/binfilter/bf_sfx2/source/doc/sfx2_docinf.cxx
--- ooo_SRC680_m144_src.orig/binfilter/bf_sfx2/source/doc/sfx2_docinf.cxx	2005-12-08 11:52:36.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/bf_sfx2/source/doc/sfx2_docinf.cxx	2005-12-08 12:51:07.000000000 +0100
@@ -353,11 +353,11 @@
 /*N*/ 				   60* aDateTime.GetMin() +
 /*N*/ 				   60L*60* aDateTime.GetHour() ));
 /*N*/ 
-/*N*/ 	BigInt aUlongMax((ULONG)ULONG_MAX);
+/*N*/ 	BigInt aUlongMax(UINT_MAX);
 /*N*/ 	aUlongMax += 1;
 /*N*/ 
-/*N*/ 	rStream<<(UINT32)(aTime % aUlongMax) ;
-/*N*/ 	rStream<<(UINT32)(aTime / aUlongMax);
+/*N*/ 	rStream<<(sal_uInt32)(aTime % aUlongMax) ;
+/*N*/ 	rStream<<(sal_uInt32)(aTime / aUlongMax);
 /*N*/ 	return rStream.GetErrorCode();
 /*N*/ }
 
@@ -368,13 +368,13 @@
 /*N*/ 	UINT32 nLow, nHigh;
 /*N*/ 	rStream >> nLow;
 /*N*/ 	rStream >> nHigh;
-/*N*/ 	BigInt aUlongMax( (ULONG)ULONG_MAX );
+/*N*/ 	BigInt aUlongMax( UINT_MAX);
 /*N*/ 	aUlongMax += 1;
 /*N*/ 	BigInt aTime = aUlongMax * BigInt( nHigh );
 /*N*/ 	aTime += nLow;
 /*N*/ 	BigInt a100nPerSecond(10000000L);
 /*N*/ 	BigInt a100nPerDay = a100nPerSecond*BigInt( 60L * 60 * 24 );
-/*N*/ 	ULONG nDays = aTime / a100nPerDay;
+/*N*/ 	sal_uInt32 nDays = aTime / a100nPerDay;
 /*N*/ 	USHORT nYears = (USHORT)
 /*N*/ 		(( nDays - ( nDays / ( 4 * 365 ) ) + ( nDays / ( 100 * 365 ) ) -
 /*N*/ 		  ( nDays / ( 400 * 365 ) ) ) / 365 );
@@ -387,12 +387,12 @@
 /*N*/ 		nDaysCount-= Date(  1, nMonths, 1601 + nYears ).GetDaysInMonth();
 /*N*/ 	}
 /*N*/ 	Date _aDate( (USHORT)( nDays + 1 ), nMonths, nYears + 1601 );
-/*N*/ 	Time _aTime( ( aTime / ( a100nPerSecond * BigInt( 60 * 60 ) ) ) %
-/*N*/ 				 BigInt( 24 ),
-/*N*/ 				 ( aTime / ( a100nPerSecond * BigInt( 60 ) ) ) %
-/*N*/ 				 BigInt( 60 ),
-/*N*/ 				 ( aTime / ( a100nPerSecond ) ) %
-/*N*/ 				 BigInt( 60 ) );
+/*N*/ 	Time _aTime( (ULONG)(sal_uInt32)(( aTime / ( a100nPerSecond * BigInt( 60 * 60 ) ) ) %
+/*N*/ 				 BigInt( 24 )),
+/*N*/ 				 (ULONG)(sal_uInt32)(( aTime / ( a100nPerSecond * BigInt( 60 ) ) ) %
+/*N*/ 				 BigInt( 60 )),
+/*N*/ 				 (ULONG)(sal_uInt32)(( aTime / ( a100nPerSecond ) ) %
+/*N*/ 				 BigInt( 60 )) );
 /*N*/ 	aDateTime = DateTime( _aDate, _aTime );
 /*N*/ 	aDateTime.ConvertToLocalTime();
 /*N*/ 	return rStream.GetErrorCode();
diff -ur ooo_SRC680_m144_src.orig/binfilter/bf_sfx2/source/inc/sfxpicklist.hxx ooo_SRC680_m144_src/binfilter/bf_sfx2/source/inc/sfxpicklist.hxx
--- ooo_SRC680_m144_src.orig/binfilter/bf_sfx2/source/inc/sfxpicklist.hxx	2005-12-08 11:52:36.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/bf_sfx2/source/inc/sfxpicklist.hxx	2005-12-08 12:18:48.000000000 +0100
@@ -81,7 +81,7 @@
 	sal_uInt32						m_nAllowedMenuSize;
 	::com::sun::star::uno::Reference< ::com::sun::star::util::XStringWidth > m_xStringLength;
 
-							SfxPickList( ULONG nMenuSize );
+							SfxPickList( sal_uInt32 nMenuSize );
 //STRIP001 							~SfxPickList();
 
 	static osl::Mutex*		GetOrCreateMutex();
diff -ur ooo_SRC680_m144_src.orig/binfilter/bf_starmath/source/starmath_parse.cxx ooo_SRC680_m144_src/binfilter/bf_starmath/source/starmath_parse.cxx
--- ooo_SRC680_m144_src.orig/binfilter/bf_starmath/source/starmath_parse.cxx	2005-12-08 11:52:36.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/bf_starmath/source/starmath_parse.cxx	2005-12-08 14:42:41.000000000 +0100
@@ -590,7 +590,7 @@
 /*N*/ 	}
 /*N*/ 	else if (aRes.TokenType & KParseType::BOOLEAN)
 /*N*/ 	{
-/*N*/ 		long   &rnEndPos = aRes.EndPos;
+/*N*/ 		sal_Int32   &rnEndPos = aRes.EndPos;
 /*N*/ 		String	aName( BufferString.Copy( nRealStart, rnEndPos - nRealStart ) );
 /*N*/ 		if (2 >= aName.Len())
 /*N*/ 		{
@@ -694,7 +694,7 @@
 /*N*/ 	}
 /*N*/ 	else if (aRes.TokenType & KParseType::ONE_SINGLE_CHAR)
 /*N*/ 	{
-/*N*/ 		long   &rnEndPos = aRes.EndPos;
+/*N*/ 		sal_Int32   &rnEndPos = aRes.EndPos;
 /*N*/ 		String	aName( BufferString.Copy( nRealStart, rnEndPos - nRealStart ) );
 /*N*/ 
 /*N*/ 		if (1 == aName.Len())
diff -ur ooo_SRC680_m144_src.orig/binfilter/bf_svx/source/editeng/editdoc.hxx ooo_SRC680_m144_src/binfilter/bf_svx/source/editeng/editdoc.hxx
--- ooo_SRC680_m144_src.orig/binfilter/bf_svx/source/editeng/editdoc.hxx	2005-12-08 11:52:36.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/bf_svx/source/editeng/editdoc.hxx	2005-12-08 17:00:12.000000000 +0100
@@ -459,7 +459,7 @@
 
 class ParaPortion;
 
-SV_DECL_VARARR( CharPosArray, long, 0, CHARPOSGROW )//STRIP008 ;
+SV_DECL_VARARR( CharPosArray, sal_Int32, 0, CHARPOSGROW )//STRIP008 ;
 
 // ------------------------------------------------------------------------
 // class EditLine
diff -ur ooo_SRC680_m144_src.orig/binfilter/bf_svx/source/editeng/svx_editdoc2.cxx ooo_SRC680_m144_src/binfilter/bf_svx/source/editeng/svx_editdoc2.cxx
--- ooo_SRC680_m144_src.orig/binfilter/bf_svx/source/editeng/svx_editdoc2.cxx	2005-12-08 11:52:36.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/bf_svx/source/editeng/svx_editdoc2.cxx	2005-12-08 17:02:54.000000000 +0100
@@ -94,7 +94,7 @@
 
 /*N*/ DBG_NAME( EE_ParaPortion )
 
-/*N*/ SV_IMPL_VARARR( CharPosArray, long );
+/*N*/ SV_IMPL_VARARR( CharPosArray, sal_Int32 );
 
 /*
 
diff -ur ooo_SRC680_m144_src.orig/binfilter/bf_svx/source/editeng/svx_editeng.cxx ooo_SRC680_m144_src/binfilter/bf_svx/source/editeng/svx_editeng.cxx
--- ooo_SRC680_m144_src.orig/binfilter/bf_svx/source/editeng/svx_editeng.cxx	2005-12-08 11:52:36.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/bf_svx/source/editeng/svx_editeng.cxx	2005-12-08 17:40:00.000000000 +0100
@@ -2333,7 +2333,7 @@
 // =====================================================================
 // ======================   Virtuelle Methoden   =======================
 // =====================================================================
-/*N*/ void __EXPORT EditEngine::DrawingText( const Point&, const XubString&, USHORT nTextStart, USHORT nTextLen, const long*, const SvxFont&, sal_uInt16 nPara, sal_uInt16 nIndex, BYTE nRightToLeft )
+/*N*/ void __EXPORT EditEngine::DrawingText( const Point&, const XubString&, USHORT nTextStart, USHORT nTextLen, const sal_Int32*, const SvxFont&, sal_uInt16 nPara, sal_uInt16 nIndex, BYTE nRightToLeft )
 /*N*/ {
 /*N*/ 	DBG_CHKTHIS( EditEngine, 0 );
 /*N*/ }
diff -ur ooo_SRC680_m144_src.orig/binfilter/bf_svx/source/editeng/svx_impedit2.cxx ooo_SRC680_m144_src/binfilter/bf_svx/source/editeng/svx_impedit2.cxx
--- ooo_SRC680_m144_src.orig/binfilter/bf_svx/source/editeng/svx_impedit2.cxx	2005-12-08 11:52:36.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/bf_svx/source/editeng/svx_impedit2.cxx	2005-12-08 14:50:16.000000000 +0100
@@ -2786,14 +2786,14 @@
 /*?*/ 	return aPaM;
 /*N*/ }
 
-/*N*/ ULONG ImpEditEngine::GetTextHeight() const
+/*N*/ sal_uInt32 ImpEditEngine::GetTextHeight() const
 /*N*/ {
 /*N*/ 	DBG_ASSERT( GetUpdateMode(), "Sollte bei Update=FALSE nicht verwendet werden: GetTextHeight" );
 /*N*/ 	DBG_ASSERT( IsFormatted() || IsFormatting(), "GetTextHeight: Nicht formatiert" );
 /*N*/ 	return nCurTextHeight;
 /*N*/ }
 
-/*N*/ ULONG ImpEditEngine::CalcTextWidth( BOOL bIgnoreExtraSpace )
+/*N*/ sal_uInt32 ImpEditEngine::CalcTextWidth( BOOL bIgnoreExtraSpace )
 /*N*/ {
 /*N*/ 	// Wenn noch nicht formatiert und nicht gerade dabei.
 /*N*/ 	// Wird in der Formatierung bei AutoPageSize gerufen.
@@ -2859,7 +2859,7 @@
 /*N*/ 	return (ULONG)nMaxWidth;
 /*N*/ }
 
-/*N*/ ULONG ImpEditEngine::CalcLineWidth( ParaPortion* pPortion, EditLine* pLine, BOOL bIgnoreExtraSpace )
+/*N*/ sal_uInt32 ImpEditEngine::CalcLineWidth( ParaPortion* pPortion, EditLine* pLine, BOOL bIgnoreExtraSpace )
 /*N*/ {
 /*N*/ 	USHORT nPara = GetEditDoc().GetPos( pPortion->GetNode() );
 /*N*/     ULONG nOldLayoutMode = GetRefDevice()->GetLayoutMode();
@@ -2907,7 +2907,7 @@
 /*N*/     return nWidth;
 /*N*/ }
 
-/*N*/ ULONG ImpEditEngine::CalcTextHeight()
+/*N*/ sal_uInt32 ImpEditEngine::CalcTextHeight()
 /*N*/ {
 /*N*/ 	DBG_ASSERT( GetUpdateMode(), "Sollte bei Update=FALSE nicht verwendet werden: CalcTextHeight" );
 /*N*/ 	ULONG nY = 0;
diff -ur ooo_SRC680_m144_src.orig/binfilter/bf_svx/source/editeng/svx_impedit3.cxx ooo_SRC680_m144_src/binfilter/bf_svx/source/editeng/svx_impedit3.cxx
--- ooo_SRC680_m144_src.orig/binfilter/bf_svx/source/editeng/svx_impedit3.cxx	2005-12-08 11:52:36.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/bf_svx/source/editeng/svx_impedit3.cxx	2005-12-08 17:06:11.000000000 +0100
@@ -777,7 +777,7 @@
 /*N*/ 	SvxFont aTmpFont( pNode->GetCharAttribs().GetDefFont() );
 /*N*/ 
 /*N*/ 	sal_Bool bCalcCharPositions = sal_True;
-/*N*/ 	long* pBuf = new long[ pNode->Len() ];
+/*N*/ 	sal_Int32* pBuf = new sal_Int32[ pNode->Len() ];
 /*N*/ 
 /*N*/ 	sal_Bool bSameLineAgain = sal_False;	// Fuer TextRanger, wenn sich die Hoehe aendert.
 /*N*/ 	TabInfo aCurrentTab;
@@ -2932,8 +2932,8 @@
 /*N*/ 								XubString aText;
 /*N*/                                 USHORT nTextStart = 0;
 /*N*/                                 USHORT nTextLen = 0;
-/*N*/ 								const long* pDXArray = 0;
-/*N*/ 								long* pTmpDXArray = 0;
+/*N*/ 								const sal_Int32* pDXArray = 0;
+/*N*/ 								sal_Int32* pTmpDXArray = 0;
 /*N*/ 
 /*N*/ 								if ( pTextPortion->GetKind() == PORTIONKIND_TEXT )
 /*N*/ 								{
@@ -2951,7 +2951,7 @@
 /*?*/                                     nTextStart = 0;
 /*?*/                                     nTextLen = aText.Len();
 /*?*/ 
-/*?*/ 									pTmpDXArray = new long[ aText.Len() ];
+/*?*/ 									pTmpDXArray = new sal_Int32[ aText.Len() ];
 /*?*/ 									pDXArray = pTmpDXArray;
 /*?*/ 									Font aOldFont( GetRefDevice()->GetFont() );
 /*?*/ 									aTmpFont.SetPhysFont( GetRefDevice() );
diff -ur ooo_SRC680_m144_src.orig/binfilter/bf_svx/source/editeng/svx_impedit4.cxx ooo_SRC680_m144_src/binfilter/bf_svx/source/editeng/svx_impedit4.cxx
--- ooo_SRC680_m144_src.orig/binfilter/bf_svx/source/editeng/svx_impedit4.cxx	2005-12-08 11:52:36.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/bf_svx/source/editeng/svx_impedit4.cxx	2005-12-08 14:51:06.000000000 +0100
@@ -1284,7 +1284,7 @@
 /*N*/ 	if ( pPortionInfo && ( (long)pPortionInfo->GetPaperWidth() == aPaperSize.Width() )
 /*N*/ 			&& ( pPortionInfo->GetRefMapMode() == GetRefDevice()->GetMapMode() ) )
 /*N*/ 	{
-/*?*/ 		if ( ( pPortionInfo->GetRefDevPtr() == (sal_uInt32)GetRefDevice() ) ||
+/*?*/ 		if ( ( pPortionInfo->GetRefDevPtr() == (sal_uIntPtr)GetRefDevice() ) ||
 /*?*/ 			 ( ( pPortionInfo->GetRefDevType() == OUTDEV_VIRDEV ) &&
 /*?*/ 			   ( GetRefDevice()->GetOutDevType() == OUTDEV_VIRDEV ) ) )
 /*?*/ 		bUsePortionInfo = sal_True;
diff -ur ooo_SRC680_m144_src.orig/binfilter/bf_svx/source/items/svx_flditem.cxx ooo_SRC680_m144_src/binfilter/bf_svx/source/items/svx_flditem.cxx
--- ooo_SRC680_m144_src.orig/binfilter/bf_svx/source/items/svx_flditem.cxx	2005-12-08 11:52:36.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/bf_svx/source/items/svx_flditem.cxx	2005-12-08 14:57:22.000000000 +0100
@@ -784,7 +784,7 @@
 /*N*/         break;
 /*N*/ 	}
 /*N*/ 
-/*N*/     ULONG nFormatKey;
+/*N*/     sal_uInt32 nFormatKey;
 /*N*/ 
 /*N*/ 	switch( eTmpFormat )
 /*N*/ 	{
diff -ur ooo_SRC680_m144_src.orig/binfilter/bf_svx/source/items/svx_svxfont.cxx ooo_SRC680_m144_src/binfilter/bf_svx/source/items/svx_svxfont.cxx
--- ooo_SRC680_m144_src.orig/binfilter/bf_svx/source/items/svx_svxfont.cxx	2005-12-08 11:52:36.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/bf_svx/source/items/svx_svxfont.cxx	2005-12-08 14:58:59.000000000 +0100
@@ -478,7 +478,7 @@
 /*N*/ }
 
 /*N*/ Size SvxFont::QuickGetTextSize( const OutputDevice *pOut, const XubString &rTxt,
-/*N*/ 						 const USHORT nIdx, const USHORT nLen, long* pDXArray ) const
+/*N*/ 						 const USHORT nIdx, const USHORT nLen, sal_Int32* pDXArray ) const
 /*N*/ {
 /*N*/ 	if ( !IsCaseMap() && !IsKern() )
 /*N*/ 		return Size( pOut->GetTextArray( rTxt, pDXArray, nIdx, nLen ),
@@ -565,7 +565,7 @@
 
 /*N*/ void SvxFont::QuickDrawText( OutputDevice *pOut,
 /*N*/ 	const Point &rPos, const XubString &rTxt,
-/*N*/ 	const xub_StrLen nIdx, const xub_StrLen nLen, const long* pDXArray ) const
+/*N*/ 	const xub_StrLen nIdx, const xub_StrLen nLen, const sal_Int32* pDXArray ) const
 /*N*/ {
 /*N*/ 	// Font muss ins OutputDevice selektiert sein...
 /*N*/ 	if ( !IsCaseMap() && !IsCapital() && !IsKern() && !IsEsc() )
diff -ur ooo_SRC680_m144_src.orig/binfilter/bf_svx/source/outliner/outleeng.hxx ooo_SRC680_m144_src/binfilter/bf_svx/source/outliner/outleeng.hxx
--- ooo_SRC680_m144_src.orig/binfilter/bf_svx/source/outliner/outleeng.hxx	2005-12-08 11:52:36.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/bf_svx/source/outliner/outleeng.hxx	2005-12-08 18:40:20.000000000 +0100
@@ -61,7 +61,7 @@
 	virtual void 		ParagraphDeleted( USHORT nDeletedParagraph );
 	
 	// #101498#
-	virtual void 		DrawingText(const Point& rStartPos, const XubString& rText, USHORT nTextStart, USHORT nTextLen, const long* pDXArray, const SvxFont& rFont, USHORT nPara, USHORT nIndex, BYTE nRightToLeft);
+	virtual void 		DrawingText(const Point& rStartPos, const XubString& rText, USHORT nTextStart, USHORT nTextLen, const sal_Int32* pDXArray, const SvxFont& rFont, USHORT nPara, USHORT nIndex, BYTE nRightToLeft);
 
 //STRIP001 	virtual	void 		StyleSheetChanged( SfxStyleSheet* pStyle );
 	virtual void 		ParaAttribsChanged( USHORT nPara );
diff -ur ooo_SRC680_m144_src.orig/binfilter/bf_svx/source/outliner/svx_outleeng.cxx ooo_SRC680_m144_src/binfilter/bf_svx/source/outliner/svx_outleeng.cxx
--- ooo_SRC680_m144_src.orig/binfilter/bf_svx/source/outliner/svx_outleeng.cxx	2005-12-08 11:52:36.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/bf_svx/source/outliner/svx_outleeng.cxx	2005-12-08 18:40:28.000000000 +0100
@@ -149,7 +149,7 @@
 /*N*/ }
 
 // #101498#
-/*N*/ void OutlinerEditEng::DrawingText( const Point& rStartPos, const XubString& rText, USHORT nTextStart, USHORT nTextLen, const long* pDXArray, const SvxFont& rFont, USHORT nPara, USHORT nIndex, BYTE nRightToLeft)
+/*N*/ void OutlinerEditEng::DrawingText( const Point& rStartPos, const XubString& rText, USHORT nTextStart, USHORT nTextLen, const sal_Int32* pDXArray, const SvxFont& rFont, USHORT nPara, USHORT nIndex, BYTE nRightToLeft)
 /*N*/ {
 /*N*/ 	if ( nIndex == 0 )
 /*N*/ 	{
diff -ur ooo_SRC680_m144_src.orig/binfilter/bf_svx/source/outliner/svx_outliner.cxx ooo_SRC680_m144_src/binfilter/bf_svx/source/outliner/svx_outliner.cxx
--- ooo_SRC680_m144_src.orig/binfilter/bf_svx/source/outliner/svx_outliner.cxx	2005-12-08 11:52:36.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/bf_svx/source/outliner/svx_outliner.cxx	2005-12-08 18:40:36.000000000 +0100
@@ -2023,7 +2023,7 @@
 /*N*/ }
 
 // #101498#
-/*N*/ void Outliner::DrawingText( const Point& rStartPos, const XubString& rText, USHORT nTextStart, USHORT nTextLen, const long* pDXArray,const SvxFont& rFont, USHORT nPara, USHORT nIndex, BYTE nRightToLeft)
+/*N*/ void Outliner::DrawingText( const Point& rStartPos, const XubString& rText, USHORT nTextStart, USHORT nTextLen, const sal_Int32* pDXArray,const SvxFont& rFont, USHORT nPara, USHORT nIndex, BYTE nRightToLeft)
 /*N*/ {
 /*N*/ 	DBG_CHKTHIS(Outliner,0);
 /*N*/ 	
diff -ur ooo_SRC680_m144_src.orig/binfilter/bf_svx/source/svdraw/svx_svdoattr.cxx ooo_SRC680_m144_src/binfilter/bf_svx/source/svdraw/svx_svdoattr.cxx
--- ooo_SRC680_m144_src.orig/binfilter/bf_svx/source/svdraw/svx_svdoattr.cxx	2005-12-08 11:52:36.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/bf_svx/source/svdraw/svx_svdoattr.cxx	2005-12-08 18:22:44.000000000 +0100
@@ -1084,11 +1084,11 @@
 /*N*/ 	nSttWdt /= 2;
 /*N*/ 
 /*N*/ 	// Lieber etwas mehr, dafuer keine Wurzel ziehen
-/*N*/ 	long nSttAdd = Max(nSttWdt, nSttHgt);
+/*N*/ 	sal_Int32 nSttAdd = Max(nSttWdt, nSttHgt);
 /*N*/ 	nSttAdd *= 3;
 /*N*/ 	nSttAdd /= 2;
 /*N*/ 
-/*N*/ 	long nEndWdt = ((const XLineEndWidthItem&)(rSet.Get(XATTR_LINEENDWIDTH))).GetValue();
+/*N*/ 	sal_Int32 nEndWdt = ((const XLineEndWidthItem&)(rSet.Get(XATTR_LINEENDWIDTH))).GetValue();
 /*N*/ 
 /*N*/ 	if(nEndWdt < 0)
 /*N*/ 		nEndWdt = -nLineWdt * nEndWdt / 100; // <0 = relativ
diff -ur ooo_SRC680_m144_src.orig/binfilter/bf_svx/source/svdraw/svx_svdopath.cxx ooo_SRC680_m144_src/binfilter/bf_svx/source/svdraw/svx_svdopath.cxx
--- ooo_SRC680_m144_src.orig/binfilter/bf_svx/source/svdraw/svx_svdopath.cxx	2005-12-08 11:52:36.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/bf_svx/source/svdraw/svx_svdopath.cxx	2005-12-08 18:28:44.000000000 +0100
@@ -79,6 +79,8 @@
 // #104018# replace macros above with type-safe methods
 inline sal_Int32 ImplTwipsToMM(sal_Int32 nVal) { return ((nVal * 127 + 36) / 72); }
 inline sal_Int32 ImplMMToTwips(sal_Int32 nVal) { return ((nVal * 72 + 63) / 127); }
+inline sal_Int64 ImplTwipsToMM(sal_Int64 nVal) { return ((nVal * 127 + 36) / 72); }
+inline sal_Int64 ImplMMToTwips(sal_Int64 nVal) { return ((nVal * 72 + 63) / 127); }
 inline double ImplTwipsToMM(double fVal) { return (fVal * (127.0 / 72.0)); }
 inline double ImplMMToTwips(double fVal) { return (fVal * (72.0 / 127.0)); }
 
diff -ur ooo_SRC680_m144_src.orig/binfilter/bf_svx/source/xoutdev/svx__xfont.cxx ooo_SRC680_m144_src/binfilter/bf_svx/source/xoutdev/svx__xfont.cxx
--- ooo_SRC680_m144_src.orig/binfilter/bf_svx/source/xoutdev/svx__xfont.cxx	2005-12-08 11:52:36.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/bf_svx/source/xoutdev/svx__xfont.cxx	2005-12-08 18:46:04.000000000 +0100
@@ -187,7 +187,7 @@
 
 // #101498# Helper method ImpGetTextLength to get text length taking into account
 // hor/vertical and BIDI, especially right-to-left.
-/*N*/ sal_Int32 ImpGetTextLength(OutputDevice* pOut, DrawPortionInfo* pInfo, long* pDXArray, 
+/*N*/ sal_Int32 ImpGetTextLength(OutputDevice* pOut, DrawPortionInfo* pInfo, sal_Int32* pDXArray, 
 /*N*/ 	xub_StrLen nIndex, xub_StrLen nLen)
 /*N*/ {
 /*N*/ 	sal_Bool bRightToLeft = pInfo->IsRTL();
@@ -266,7 +266,7 @@
 /*N*/ 	sal_Bool bToLastPoint, sal_Bool bDraw, sal_Bool bIsShadow)
 /*N*/ {
 /*N*/ 	Font aFont = pInfo->rFont;
-/*N*/ 	const long* pDXArray = pInfo->pDXArray;
+/*N*/ 	const sal_Int32* pDXArray = pInfo->pDXArray;
 /*N*/ 	sal_Bool bUseBreakIterator(sal_False);
 /*N*/ 
 /*N*/ 	Reference < ::com::sun::star::i18n::XBreakIterator > xBreak;
@@ -348,7 +348,7 @@
 /*N*/ 		pDXArray = NULL;
 /*N*/ 	}
 /*N*/ 
-/*N*/ 	nTextWidth = ImpGetTextLength(pOut, pInfo, (long*) pDXArray, 0, pInfo->nTextLen);
+/*N*/ 	nTextWidth = ImpGetTextLength(pOut, pInfo, (sal_Int32*) pDXArray, 0, pInfo->nTextLen);
 /*N*/ 
 /*N*/ 	if ( eFormTextAdjust != XFT_LEFT && nAbsStart <= 0 )
 /*N*/ 	{
@@ -443,7 +443,7 @@
 /*N*/ 		fLen = sqrt(fDx * fDx + fDy * fDy);
 /*N*/ 		nLen = (long) (fLen + 0.5);
 /*N*/ 
-/*N*/ 		nChar1Len = ImpGetTextLength(pOut, pInfo, (long*) pDXArray, nChar, nGlyphLen);
+/*N*/ 		nChar1Len = ImpGetTextLength(pOut, pInfo, (sal_Int32*) pDXArray, nChar, nGlyphLen);
 /*N*/ 
 /*N*/ 		double fXDist, fYDist;
 /*N*/ 		double fCos = fDx;
@@ -498,7 +498,7 @@
 /*N*/ 						CharacterIteratorMode::SKIPCELL, 1, nDone) - (nChar + pInfo->nTextStart + nCnt);
 /*N*/ 				}
 /*N*/ 
-/*N*/ 				nTextLen = ImpGetTextLength(pOut, pInfo, (long*) pDXArray, nChar, nCnt + nNextGlyphLen);
+/*N*/ 				nTextLen = ImpGetTextLength(pOut, pInfo, (sal_Int32*) pDXArray, nChar, nCnt + nNextGlyphLen);
 /*N*/ 
 /*N*/ 				nCnt += nNextGlyphLen;
 /*N*/ 			}
@@ -567,7 +567,7 @@
 /*?*/ 						pOut->SetFont(aFont);
 /*?*/ 						if(bDraw)
 /*?*/ 						{DBG_BF_ASSERT(0, "STRIP"); //STRIP001 
-//STRIP001 /*?*/ 							ImpDrawTextArray(pOut, aPos, pInfo, (long*)pDXArray, nChar, nCnt);
+//STRIP001 /*?*/ 							ImpDrawTextArray(pOut, aPos, pInfo, (sal_Int32*)pDXArray, nChar, nCnt);
 /*?*/ 						}
 /*N*/ 					}
 /*N*/ 					else
@@ -579,7 +579,7 @@
 /*N*/ 						pOut->SetFont(aFont);
 /*N*/ 						if(bDraw)
 /*N*/ 						{
-/*?*/ 							DBG_BF_ASSERT(0, "STRIP"); //STRIP001 ImpDrawTextArray(pOut, aPos, pInfo, (long*)pDXArray, nChar, nCnt);
+/*?*/ 							DBG_BF_ASSERT(0, "STRIP"); //STRIP001 ImpDrawTextArray(pOut, aPos, pInfo, (sal_Int32*)pDXArray, nChar, nCnt);
 /*N*/ 						}
 /*N*/ 					}
 /*N*/ 				}
@@ -606,7 +606,7 @@
 /*?*/ 					{
 /*?*/ 						long nW;
 /*?*/ 
-/*?*/ 						nW = ImpGetTextLength(pOut, pInfo, (long*) pDXArray, nChar, i);
+/*?*/ 						nW = ImpGetTextLength(pOut, pInfo, (sal_Int32*) pDXArray, nChar, i);
 /*?*/ 
 /*?*/ 						aPolyPos.X() += (long) (fDx * nW / fLen);
 /*?*/ 						aPolyPos.Y() += (long) (fDy * nW / fLen);
@@ -657,7 +657,7 @@
 /*?*/ 					{
 /*?*/ 						long nW;
 /*?*/ 
-/*?*/ 						nW = ImpGetTextLength(pOut, pInfo, (long*) pDXArray, nChar + i, nNextGlyphLen);
+/*?*/ 						nW = ImpGetTextLength(pOut, pInfo, (sal_Int32*) pDXArray, nChar + i, nNextGlyphLen);
 /*?*/ 
 /*?*/ 						aPolyPos.X() -= nW / 2;
 /*?*/ 
@@ -678,7 +678,7 @@
 /*?*/ 							DrawXPolyPolygon(aChar);
 /*?*/ 						else
 /*?*/ 						{
-/*?*/ 						DBG_BF_ASSERT(0, "STRIP"); //STRIP001 	ImpDrawTextArray(pOut, aPolyPos, pInfo, (long*)pDXArray, nChar + i, nNextGlyphLen);
+/*?*/ 						DBG_BF_ASSERT(0, "STRIP"); //STRIP001 	ImpDrawTextArray(pOut, aPolyPos, pInfo, (sal_Int32*)pDXArray, nChar + i, nNextGlyphLen);
 /*?*/ 						}
 /*?*/ 					}
 /*?*/ 
diff -ur ooo_SRC680_m144_src.orig/binfilter/inc/bf_sc/document.hxx ooo_SRC680_m144_src/binfilter/inc/bf_sc/document.hxx
--- ooo_SRC680_m144_src.orig/binfilter/inc/bf_sc/document.hxx	2005-12-08 11:52:37.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/inc/bf_sc/document.hxx	2005-12-08 14:04:09.000000000 +0100
@@ -759,8 +759,8 @@
 	void			GetValue( USHORT nCol, USHORT nRow, USHORT nTab, double& rValue );
 	double			RoundValueAsShown( double fVal, ULONG nFormat );
 	void			GetNumberFormat( USHORT nCol, USHORT nRow, USHORT nTab,
-									 ULONG& rFormat );
-	ULONG			GetNumberFormat( const ScAddress& ) const;
+									 sal_uInt32& rFormat );
+	sal_uInt32			GetNumberFormat( const ScAddress& ) const;
 					/// if no number format attribute is set the calculated
 					/// number format of the formula cell is returned
 	void			GetNumberFormatInfo( short& nType, ULONG& nIndex,
diff -ur ooo_SRC680_m144_src.orig/binfilter/inc/bf_sch/memchrt.hxx ooo_SRC680_m144_src/binfilter/inc/bf_sch/memchrt.hxx
--- ooo_SRC680_m144_src.orig/binfilter/inc/bf_sch/memchrt.hxx	2005-12-08 11:52:37.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/inc/bf_sch/memchrt.hxx	2005-12-08 12:14:11.000000000 +0100
@@ -284,28 +284,28 @@
 	// BM: Fix for #68864#
 	// Use these four methods with care! The arrays MUST have the correct size!
 	// ********************
-	void SetRowTranslation( const long* pTransTable )
+	void SetRowTranslation( const sal_Int32* pTransTable )
 	{
 		if( !pRowTable ) return;
-		for( long i=0; i<nRowCnt; i++ )
+		for( sal_Int32 i=0; i<nRowCnt; i++ )
 			pRowTable[ i ] = pTransTable[ i ];
 	}
-	void SetColTranslation( const long* pTransTable )
+	void SetColTranslation( const sal_Int32* pTransTable )
 	{
 		if( !pColTable ) return;
-		for( long i=0; i<nColCnt; i++ )
+		for( sal_Int32 i=0; i<nColCnt; i++ )
 			pColTable[ i ] = pTransTable[ i ];
 	}
-	void SetRowNumFmtTable( const long* pNumFmtTable )
+	void SetRowNumFmtTable( const sal_Int32* pNumFmtTable )
 	{
 		if( !pRowNumFmtId ) return;
-		for( long i=0; i<nRowCnt; i++ )
+		for( sal_Int32 i=0; i<nRowCnt; i++ )
 			pRowNumFmtId[ i ] = pNumFmtTable[ i ];
 	}
-	void SetColNumFmtTable( const long* pNumFmtTable )
+	void SetColNumFmtTable( const sal_Int32* pNumFmtTable )
 	{
 		if( !pColNumFmtId ) return;
-		for( long i=0; i<nColCnt; i++ )
+		for( sal_Int32 i=0; i<nColCnt; i++ )
 			pColNumFmtId[ i ] = pNumFmtTable[ i ];
 	}
 	// this is only valid if the corresponding translation table was set correctly!
diff -ur ooo_SRC680_m144_src.orig/binfilter/inc/bf_sfx2/dispatch.hxx ooo_SRC680_m144_src/binfilter/inc/bf_sfx2/dispatch.hxx
--- ooo_SRC680_m144_src.orig/binfilter/inc/bf_sfx2/dispatch.hxx	2005-12-08 11:52:37.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/inc/bf_sfx2/dispatch.hxx	2005-12-08 12:35:17.000000000 +0100
@@ -139,7 +139,7 @@
 	DECL_LINK( PostMsgHandler, SfxRequest * );
 
 	int 				Call_Impl( SfxShell& rShell, const SfxSlot &rSlot, SfxRequest &rReq, BOOL bRecord );
-	ULONG               _Update_Impl( BOOL,BOOL,BOOL,SfxMenuBarManager*,SfxWorkWindow*);
+	sal_uInt32			_Update_Impl( BOOL,BOOL,BOOL,SfxMenuBarManager*,SfxWorkWindow*);
 	void				CollectTools_Impl(SfxWorkWindow*);
 
 protected:
@@ -234,8 +234,8 @@
 
 	BOOL                IsAllowed( USHORT nSlot ) const;
     ::com::sun::star::frame::XDispatch*          GetDispatchInterface( const String& );
-	void				SetDisableFlags( ULONG nFlags );
-	ULONG				GetDisableFlags() const;
+	void				SetDisableFlags( sal_uInt32 nFlags );
+	sal_uInt32				GetDisableFlags() const;
 
 #if _SOLAR__PRIVATE
 	BOOL				HasSlot_Impl( USHORT );
diff -ur ooo_SRC680_m144_src.orig/binfilter/inc/bf_sfx2/docfac.hxx ooo_SRC680_m144_src/binfilter/inc/bf_sfx2/docfac.hxx
--- ooo_SRC680_m144_src.orig/binfilter/inc/bf_sfx2/docfac.hxx	2005-12-08 11:52:37.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/inc/bf_sfx2/docfac.hxx	2005-12-08 12:40:04.000000000 +0100
@@ -144,7 +144,7 @@
 	void        	RegisterFilter( const String &rName,
 									const String &rWildcard,
 									SfxFilterFlags nFlags,
-									ULONG lFormat,
+									sal_uInt32 lFormat,
 									const String &rMacType,
 									const String &rTypeName,
 									USHORT nIconId,
diff -ur ooo_SRC680_m144_src.orig/binfilter/inc/bf_sfx2/docfilt.hxx ooo_SRC680_m144_src/binfilter/inc/bf_sfx2/docfilt.hxx
--- ooo_SRC680_m144_src.orig/binfilter/inc/bf_sfx2/docfilt.hxx	2005-12-08 11:52:37.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/inc/bf_sfx2/docfilt.hxx	2005-12-08 12:42:28.000000000 +0100
@@ -107,7 +107,7 @@
 					SfxFilter( const String &rName,
 							   const String &rWildCard,
 							   SfxFilterFlags nFormatType,
-							   ULONG lFormat,		// Clipboardformat
+							   sal_uInt32 lFormat,		// Clipboardformat
 							   const String &rMacType,	// Dateityp (MAC)
 							   const String &rTypeName, // Dateityp als String (OS/2)
 							   USHORT nDocIcon,         // Dokumenticon OS/2
diff -ur ooo_SRC680_m144_src.orig/binfilter/inc/bf_sfx2/fcontnr.hxx ooo_SRC680_m144_src/binfilter/inc/bf_sfx2/fcontnr.hxx
--- ooo_SRC680_m144_src.orig/binfilter/inc/bf_sfx2/fcontnr.hxx	2005-12-08 11:52:37.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/inc/bf_sfx2/fcontnr.hxx	2005-12-08 12:30:11.000000000 +0100
@@ -130,7 +130,7 @@
 	virtual const SfxFilter* GetFilter4Mime(
 		const String& rMime, SfxFilterFlags nMust = SFX_FILTER_IMPORT, SfxFilterFlags nDont = SFX_FILTER_NOTINSTALLED ) const;
 	virtual const SfxFilter* GetFilter4ClipBoardId(
-		ULONG nId, SfxFilterFlags nMust = SFX_FILTER_IMPORT, SfxFilterFlags nDont = SFX_FILTER_NOTINSTALLED ) const;
+		sal_uInt32 nId, SfxFilterFlags nMust = SFX_FILTER_IMPORT, SfxFilterFlags nDont = SFX_FILTER_NOTINSTALLED ) const;
 	virtual const SfxFilter* GetFilter4EA(
 		const String& rEA, SfxFilterFlags nMust = SFX_FILTER_IMPORT, SfxFilterFlags nDont = SFX_FILTER_NOTINSTALLED ) const;
 	virtual const SfxFilter* GetFilter4Extension(
@@ -146,7 +146,7 @@
 	}
     const SfxFilter* GetFilter4Protocol(
         const String& rURL, SfxFilterFlags nMust = 0, SfxFilterFlags nDont = SFX_FILTER_NOTINSTALLED ) const;
-	virtual ULONG            GetFilter4Content(
+	virtual sal_uInt32       GetFilter4Content(
 		SfxMedium& rMedium, const SfxFilter**, SfxFilterFlags nMust = SFX_FILTER_IMPORT, SfxFilterFlags nDont = SFX_FILTER_NOTINSTALLED ) const ;
 	virtual const SfxFilter* GetFilter4Protocol(
 		SfxMedium& rMed, SfxFilterFlags nMust = 0, SfxFilterFlags nDont = SFX_FILTER_NOTINSTALLED ) const;
@@ -157,7 +157,7 @@
 
 	virtual USHORT           GetFilterCount() const;
 	virtual const SfxFilter* GetFilter( USHORT ) const;
-	virtual ULONG            Execute( SfxMedium& rMedium, SfxFrame*& rpFrame ) const ;
+	virtual sal_uInt32       Execute( SfxMedium& rMedium, SfxFrame*& rpFrame ) const ;
 
 //STRIP001 	BOOL                     IsUsableForRedirects() const;
 
@@ -226,7 +226,7 @@
 							 ~SfxExecutableFilterContainer();
 
 	virtual const SfxFilter* GetFilter4Protocol( SfxMedium& rMed, SfxFilterFlags nMust = 0, SfxFilterFlags nDont = SFX_FILTER_NOTINSTALLED ) const;
-	virtual ULONG            Execute( SfxMedium& rMedium, SfxFrame*& ) const ;
+	virtual sal_uInt32       Execute( SfxMedium& rMedium, SfxFrame*& ) const ;
 
 	static const SfxFilter*  CheckForFolder( SfxMedium& rMed, SfxFilterFlags nMust = 0, SfxFilterFlags nDont = SFX_FILTER_NOTINSTALLED );
 //STRIP001 	static const SfxFilter*  GetDownloadFilter();
@@ -239,7 +239,7 @@
 {
 public:
 	SfxExternalAppFilterContainer();
-	virtual ULONG            Execute( SfxMedium& rMedium, SfxFrame*& ) const;
+	virtual sal_uInt32       Execute( SfxMedium& rMedium, SfxFrame*& ) const;
 	virtual const SfxFilter* GetFilter4FilterName(
 		const String& rName, SfxFilterFlags nMust = 0, SfxFilterFlags nDont = SFX_FILTER_NOTINSTALLED ) const;
 	virtual USHORT           GetFilterCount() const;
@@ -253,7 +253,7 @@
 	DECL_LINK( 					LoadHdl_Impl, void* );
 public:
 								SfxPluginFilterContainer();
-	virtual ULONG            	Execute( SfxMedium& rMedium, SfxFrame*& ) const;
+	virtual sal_uInt32            	Execute( SfxMedium& rMedium, SfxFrame*& ) const;
 	virtual USHORT           	GetFilterCount() const;
 	virtual const SfxFilter* 	GetFilter4Protocol( SfxMedium& rMed, SfxFilterFlags nMust = 0, SfxFilterFlags nDont = SFX_FILTER_NOTINSTALLED ) const;
 };
@@ -269,7 +269,7 @@
 	SfxFactoryFilterContainer(
 		const String& rName, const SfxObjectFactory& rFactP );
 	void SetDetectFilter( SfxDetectFilter pFuncP ) { pFunc = pFuncP; }
-	virtual ULONG GetFilter4Content(
+	virtual sal_uInt32 GetFilter4Content(
 		SfxMedium& rMedium, const SfxFilter **,
 		SfxFilterFlags nMust = SFX_FILTER_IMPORT, SfxFilterFlags nDont = SFX_FILTER_NOTINSTALLED ) const ;
 	const SfxObjectFactory& GetFactory() const { return rFact; }
@@ -291,25 +291,25 @@
 //STRIP001 	USHORT                    GetContainerCount() const;
 //STRIP001 	SfxFilterContainer*       GetContainer( USHORT nPos ) const;
 	SfxFilterContainer*       GetContainer( const String& rName ) const;
-	ULONG                     GuessFilterIgnoringContent(
+	sal_uInt32                     GuessFilterIgnoringContent(
 		SfxMedium& rMedium, const SfxFilter **,
 		SfxFilterFlags nMust = SFX_FILTER_IMPORT, SfxFilterFlags nDont = SFX_FILTER_NOTINSTALLED ) const;
-	ULONG                     GuessFilter(
+	sal_uInt32                     GuessFilter(
 		SfxMedium& rMedium, const SfxFilter **,
 		SfxFilterFlags nMust = SFX_FILTER_IMPORT, SfxFilterFlags nDont = SFX_FILTER_NOTINSTALLED ) const;
-//STRIP001 	ULONG                     DetectFilter(
+//STRIP001 	sal_uInt32                     DetectFilter(
 //STRIP001 		SfxMedium& rMedium, const SfxFilter **, BOOL bPlugIn,
 //STRIP001 		BOOL bAPI = FALSE ) const;
 //STRIP001 	const SfxFilter*          GetFilter4Mime(
 //STRIP001 		const String& rMime, SfxFilterFlags nMust = SFX_FILTER_IMPORT, SfxFilterFlags nDont = SFX_FILTER_NOTINSTALLED) const;
 	const SfxFilter*          GetFilter4ClipBoardId(
-		ULONG nId, SfxFilterFlags nMust = SFX_FILTER_IMPORT, SfxFilterFlags nDont = SFX_FILTER_NOTINSTALLED ) const;
+		sal_uInt32 nId, SfxFilterFlags nMust = SFX_FILTER_IMPORT, SfxFilterFlags nDont = SFX_FILTER_NOTINSTALLED ) const;
 	const SfxFilter*          GetFilter4EA(
 		const String& rEA, SfxFilterFlags nMust = SFX_FILTER_IMPORT, SfxFilterFlags nDont = SFX_FILTER_NOTINSTALLED ) const;
 	const SfxFilter*          GetFilter4Extension(
 		const String& rExt, SfxFilterFlags nMust = SFX_FILTER_IMPORT, SfxFilterFlags nDont = SFX_FILTER_NOTINSTALLED ) const;
 
-/*STRIP003*/ 	ULONG                     GetFilter4Content(
+/*STRIP003*/ 	sal_uInt32                     GetFilter4Content(
 /*STRIP003*/ 		SfxMedium& rMedium, const SfxFilter**, SfxFilterFlags nMust = SFX_FILTER_IMPORT, SfxFilterFlags nDont = SFX_FILTER_NOTINSTALLED, BOOL bOnlyGoodOnes=FALSE ) const ;
 	const SfxFilter*          GetFilter4Protocol(
 		SfxMedium& rMed, SfxFilterFlags nMust = SFX_FILTER_IMPORT, SfxFilterFlags nDont = SFX_FILTER_NOTINSTALLED ) const;
diff -ur ooo_SRC680_m144_src.orig/binfilter/inc/bf_sfx2/viewfrm.hxx ooo_SRC680_m144_src/binfilter/inc/bf_sfx2/viewfrm.hxx
--- ooo_SRC680_m144_src.orig/binfilter/inc/bf_sfx2/viewfrm.hxx	2005-12-08 11:52:37.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/inc/bf_sfx2/viewfrm.hxx	2005-12-08 12:56:45.000000000 +0100
@@ -112,8 +112,8 @@
 							SFX_DECL_INTERFACE(SFX_INTERFACE_SFXVIEWFRM);
 
 							SfxViewFrame() {}
-							SfxViewFrame( SfxBindings&, SfxFrame*, SfxObjectShell *pDoc=0, ULONG nType = 0 );
-//STRIP001 							SfxViewFrame(SfxObjectShell&, SfxBindings&, SfxFrame*p=0, ULONG nType = 0);
+							SfxViewFrame( SfxBindings&, SfxFrame*, SfxObjectShell *pDoc=0, sal_uInt32 nType = 0 );
+//STRIP001 							SfxViewFrame(SfxObjectShell&, SfxBindings&, SfxFrame*p=0, sal_uInt32 nType = 0);
 //STRIP001 							SfxViewFrame(
 //STRIP001 								const SfxViewFrame &, SfxBindings &, SfxFrame *pFrame);
 
diff -ur ooo_SRC680_m144_src.orig/binfilter/inc/bf_svx/editstat.hxx ooo_SRC680_m144_src/binfilter/inc/bf_svx/editstat.hxx
--- ooo_SRC680_m144_src.orig/binfilter/inc/bf_svx/editstat.hxx	2005-12-08 11:52:37.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/inc/bf_svx/editstat.hxx	2005-12-08 14:45:54.000000000 +0100
@@ -102,7 +102,7 @@
 	EE_STAT_CRSRLEFTPARA zur Zeit bei Cursorbewegungen und Return.
 */
 
-inline void SetFlags( ULONG& rBits, const ULONG nMask, FASTBOOL bOn )
+inline void SetFlags( sal_uInt32& rBits, const sal_uInt32 nMask, FASTBOOL bOn )
 {
 	if ( bOn )
 		rBits |= nMask;
@@ -113,22 +113,22 @@
 class EditStatus
 {
 protected:
-	ULONG	nStatusBits;
-	ULONG	nControlBits;
+	sal_uInt32	nStatusBits;
+	sal_uInt32	nControlBits;
 	USHORT	nPrevPara;					// fuer EE_STAT_CRSRLEFTPARA
 
 public:
 			EditStatus()				{ nStatusBits = 0; nControlBits = 0; nPrevPara = 0xFFFF; }
 
 	void	Clear() 					{ nStatusBits = 0; }
-	void	SetControlBits( ULONG nMask, FASTBOOL bOn )
+	void	SetControlBits( sal_uInt32 nMask, FASTBOOL bOn )
 				{ SetFlags( nControlBits, nMask, bOn ); }
 
-	ULONG	GetStatusWord() const		{ return nStatusBits; }
-	ULONG&	GetStatusWord() 			{ return nStatusBits; }
+	sal_uInt32	GetStatusWord() const		{ return nStatusBits; }
+	sal_uInt32&	GetStatusWord() 			{ return nStatusBits; }
 
-	ULONG	GetControlWord() const		{ return nControlBits; }
-	ULONG&	GetControlWord() 			{ return nControlBits; }
+	sal_uInt32	GetControlWord() const		{ return nControlBits; }
+	sal_uInt32&	GetControlWord() 			{ return nControlBits; }
 
 	USHORT	GetPrevParagraph() const	{ return nPrevPara; }
 	USHORT&	GetPrevParagraph() 			{ return nPrevPara; }
diff -ur ooo_SRC680_m144_src.orig/binfilter/inc/bf_svx/lrspitem.hxx ooo_SRC680_m144_src/binfilter/inc/bf_svx/lrspitem.hxx
--- ooo_SRC680_m144_src.orig/binfilter/inc/bf_svx/lrspitem.hxx	2005-12-08 11:52:37.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/inc/bf_svx/lrspitem.hxx	2005-12-08 14:56:32.000000000 +0100
@@ -97,8 +97,8 @@
 	TYPEINFO();
 
 	SvxLRSpaceItem( const USHORT nId = ITEMID_LRSPACE );
-	SvxLRSpaceItem( const long nLeft, const long nRight,
-					const long nTLeft = 0, const short nOfset = 0,
+	SvxLRSpaceItem( const sal_Int32 nLeft, const sal_Int32 nRight,
+					const sal_Int32 nTLeft = 0, const short nOfset = 0,
 					const USHORT nId = ITEMID_LRSPACE );
 	inline SvxLRSpaceItem& operator=( const SvxLRSpaceItem &rCpy );
 
diff -ur ooo_SRC680_m144_src.orig/binfilter/inc/bf_svx/outliner.hxx ooo_SRC680_m144_src/binfilter/inc/bf_svx/outliner.hxx
--- ooo_SRC680_m144_src.orig/binfilter/inc/bf_svx/outliner.hxx	2005-12-08 11:52:37.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/inc/bf_svx/outliner.hxx	2005-12-08 18:33:25.000000000 +0100
@@ -416,7 +416,7 @@
 
     const SvxFont&  rFont;
 
-    const long*     pDXArray;
+    const sal_Int32*     pDXArray;
 
 	// #101498# BiDi level needs to be transported, too.
 	BYTE			mnBiDiLevel;
@@ -425,7 +425,7 @@
 	sal_Bool IsRTL() const;
 
     DrawPortionInfo( const Point& rPos, const String& rTxt, USHORT nTxtStart, USHORT nTxtLen, 
-		const SvxFont& rFnt, USHORT nPar, xub_StrLen nIdx, const long* pDXArr, BYTE nBiDiLevel) 
+		const SvxFont& rFnt, USHORT nPar, xub_StrLen nIdx, const sal_Int32* pDXArr, BYTE nBiDiLevel) 
         :	rStartPos(rPos), rText(rTxt), rFont(rFnt), nPara(nPar), nIndex(nIdx), 
 			pDXArray(pDXArr), mnBiDiLevel(nBiDiLevel)
 	    {
@@ -795,7 +795,7 @@
 
 	// #101498#
 	virtual void    DrawingText( const Point& rStartPos, const String& rText, USHORT nTextStart, USHORT nTextLen, 
-						const long* pDXArray, const SvxFont& rFont,
+						const sal_Int32* pDXArray, const SvxFont& rFont,
 						USHORT nPara, xub_StrLen nIndex, BYTE nRightToLeft);
 
 	Size            CalcTextSize();
diff -ur ooo_SRC680_m144_src.orig/binfilter/inc/bf_svx/svxfont.hxx ooo_SRC680_m144_src/binfilter/inc/bf_svx/svxfont.hxx
--- ooo_SRC680_m144_src.orig/binfilter/inc/bf_svx/svxfont.hxx	2005-12-08 11:52:37.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/inc/bf_svx/svxfont.hxx	2005-12-08 15:00:03.000000000 +0100
@@ -120,10 +120,10 @@
 //STRIP001 			   const USHORT nIdx = 0, const USHORT nLen = STRING_LEN ) const;
 
 	void QuickDrawText( OutputDevice *pOut, const Point &rPos, const String &rTxt,
-			   const USHORT nIdx = 0, const USHORT nLen = STRING_LEN, const long* pDXArray = NULL ) const;
+			   const USHORT nIdx = 0, const USHORT nLen = STRING_LEN, const sal_Int32* pDXArray = NULL ) const;
 
 	Size QuickGetTextSize( const OutputDevice *pOut, const String &rTxt,
-						 const USHORT nIdx, const USHORT nLen, long* pDXArray = NULL ) const;
+						 const USHORT nIdx, const USHORT nLen, sal_Int32* pDXArray = NULL ) const;
 
 //STRIP001 	void DrawPrev( OutputDevice* pOut, Printer* pPrinter,
 //STRIP001 				   const Point &rPos, const String &rTxt,
diff -ur ooo_SRC680_m144_src.orig/binfilter/inc/bf_svx/xoutx.hxx ooo_SRC680_m144_src/binfilter/inc/bf_svx/xoutx.hxx
--- ooo_SRC680_m144_src.orig/binfilter/inc/bf_svx/xoutx.hxx	2005-12-08 11:52:37.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/inc/bf_svx/xoutx.hxx	2005-12-08 18:34:01.000000000 +0100
@@ -211,11 +211,11 @@
 	//long				ImpDrawFormText(const String& rText, const Polygon& rPoly,
 	//									Font aFont, long nAbsStart, BOOL bIsShadow,
 	//									BOOL bToLastPoint, BOOL bDraw,
-	//									const long* pDXArray = NULL);
+	//									const sal_Int32* pDXArray = NULL);
 	//void				DrawFormTextShadow(const String& rText, const Polygon& rPoly,
 	//									   const Font& rFont, long nAbsStart,
 	//									   BOOL bToLastPoint, BOOL bDraw,
-	//									   const long* pDXArray = NULL);
+	//									   const sal_Int32* pDXArray = NULL);
 
 //STRIP001 	void				ImpDrawBitmapFill( const Rectangle& rRect, BOOL bPrinter );
 //STRIP001 	void				ImpCalcBmpFillStartValues( const Rectangle& rRect, BOOL bPrinter );
@@ -266,7 +266,7 @@
 	//long				DrawFormText(const String& rText, const XPolygon& rXPoly,
 	//								 Font aFont, long nAbsStart = 0,
 	//								 BOOL bToLastPoint = TRUE, BOOL bDraw = TRUE,
-	//								 const long* pDXArray = NULL);
+	//								 const sal_Int32* pDXArray = NULL);
 
 	const Rectangle&	GetFormTextBoundRect() const { return aFormTextBoundRect; }
 

diff -ur ooo_SRC680_m144_src.orig/binfilter/bf_sc/source/core/tool/sc_interpr1.cxx ooo_SRC680_m144_src/binfilter/bf_sc/source/core/tool/sc_interpr1.cxx
--- ooo_SRC680_m144_src.orig/binfilter/bf_sc/source/core/tool/sc_interpr1.cxx	2005-12-08 11:52:35.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/bf_sc/source/core/tool/sc_interpr1.cxx	2005-12-08 13:23:44.000000000 +0100
@@ -1770,7 +1770,7 @@
 void ScInterpreter::ScValue()
 {
 	String aInputString = GetString();
-	ULONG nFIndex = 0;					// damit default Land/Spr.
+	sal_uInt32 nFIndex = 0;					// damit default Land/Spr.
 	double fVal;
 	if (pFormatter->IsNumberFormat(aInputString, nFIndex, fVal))
 		PushDouble(fVal);
@@ -2080,7 +2080,7 @@
 /*?*/ 				if( eFunc == ifCOUNT )
 /*?*/ 				{
 /*?*/ 					String aStr( PopString() );
 /*?*/ 					ULONG nFIndex = 0;					// damit default Land/Spr.
 /*?*/ 					if ( bTextAsZero || pFormatter->IsNumberFormat(aStr, nFIndex, fVal))
 /*?*/ 						nCount++;
 /*?*/ 				}
@@ -3074,7 +3074,7 @@
  			else if( rString.Len() )
  			{
  				rParam.FillInExcelSyntax(rString,(USHORT) 0);
- 				ULONG nIndex = 0;
+ 				sal_uInt32 nIndex = 0;
  				rEntry.bQueryByString =
  					!(pFormatter->IsNumberFormat(
  						*rEntry.pStr, nIndex, rEntry.nVal));
@@ -3244,7 +3244,7 @@
  			else
  			{
  				rParam.FillInExcelSyntax(rString,(USHORT) 0);
- 				ULONG nIndex = 0;
+ 				sal_uInt32 nIndex = 0;
  				rEntry.bQueryByString =
  					!(pFormatter->IsNumberFormat(
  						*rEntry.pStr, nIndex, rEntry.nVal));
@@ -4346,7 +4346,7 @@
 						ScQueryEntry& rEntry = rParam.GetEntry(i);
 						if ( rEntry.bDoQuery )
 						{
-							ULONG nIndex = 0;
+							sal_uInt32 nIndex = 0;
 							rEntry.bQueryByString = !pFormatter->IsNumberFormat(
 								*rEntry.pStr, nIndex, rEntry.nVal );
 							if ( rEntry.bQueryByString && !rParam.bRegExp )
@@ -2080,7 +2080,7 @@
 /*?*/ 				{
 /*?*/ 					String aStr( PopString() );
-/*?*/ 					ULONG nFIndex = 0;					// damit default Land/Spr.
+/*?*/ 					sal_uInt32 nFIndex = 0;					// damit default Land/Spr.
 /*?*/ 					if ( bTextAsZero || pFormatter->IsNumberFormat(aStr, nFIndex, fVal))
 /*?*/ 						nCount++;
diff -ur ooo_SRC680_m144_src.orig/binfilter/inc/bf_svx/editeng.hxx ooo_SRC680_m144_src/binfilter/inc/bf_svx/editeng.hxx
--- ooo_SRC680_m144_src.orig/binfilter/inc/bf_svx/editeng.hxx	2005-12-08 11:52:37.000000000 +0100
+++ ooo_SRC680_m144_src/binfilter/inc/bf_svx/editeng.hxx	2005-12-08 17:06:44.000000000 +0100
@@ -196,19 +196,19 @@
 
 	String			GetText( LineEnd eEnd = LINEEND_LF ) const;
 	String			GetText( const ESelection& rSelection, const LineEnd eEnd = LINEEND_LF ) const;
-	ULONG			GetTextLen() const;
-	ULONG			GetTextHeight() const;
-	ULONG			CalcTextWidth();
+	sal_uInt32		GetTextLen() const;
+	sal_uInt32		GetTextHeight() const;
+	sal_uInt32		CalcTextWidth();
 
 	String 			GetText( USHORT nParagraph ) const;
 	xub_StrLen			GetTextLen( USHORT nParagraph ) const;
-	ULONG			GetTextHeight( USHORT nParagraph ) const;
+	sal_uInt32		GetTextHeight( USHORT nParagraph ) const;
 
 	USHORT 			GetParagraphCount() const;
 
 	USHORT			GetLineCount( USHORT nParagraph ) const;
 	xub_StrLen		GetLineLen( USHORT nParagraph, USHORT nLine ) const;
-	ULONG			GetLineHeight( USHORT nParagraph, USHORT nLine = 0 );
+	sal_uInt32		GetLineHeight( USHORT nParagraph, USHORT nLine = 0 );
 	USHORT			GetFirstLineOffset( USHORT nParagraph );
 	ParagraphInfos 	GetParagraphInfos( USHORT nPara );
 	USHORT			FindParagraph( long nDocPosY );
@@ -289,9 +289,9 @@
 //STRIP001 	void			Draw( OutputDevice* pOutDev, const Rectangle& rOutRect, const Point& rStartDocPos, BOOL bClip );
 //STRIP001 	void			Draw( OutputDevice* pOutDev, const Point& rStartPos, short nOrientation = 0 );
 
-//  ULONG: Fehlercode des Streams.
-	ULONG			Read( SvStream& rInput, EETextFormat, SvKeyValueIterator* pHTTPHeaderAttrs = NULL );
-	ULONG			Write( SvStream& rOutput, EETextFormat );
+//  sal_uInt32: Fehlercode des Streams.
+	sal_uInt32			Read( SvStream& rInput, EETextFormat, SvKeyValueIterator* pHTTPHeaderAttrs = NULL );
+	sal_uInt32			Write( SvStream& rOutput, EETextFormat );
 
 	void			SetStatusEventHdl( const Link& rLink );
 //STRIP001 	Link			GetStatusEventHdl() const;
@@ -306,8 +306,8 @@
 	BOOL			IsFlatMode() const;
 //STRIP001 	void			SetFlatMode( BOOL bFlat );
 
-	void			SetControlWord( ULONG nWord );
-	ULONG			GetControlWord() const;
+	void			SetControlWord( sal_uInt32 nWord );
+	sal_uInt32		GetControlWord() const;
 
 	void			QuickSetAttribs( const SfxItemSet& rSet, const ESelection& rSel );
 	void 			QuickRemoveCharAttribs( USHORT nPara, USHORT nWhich = 0 );
@@ -400,7 +400,7 @@
 	virtual	void	ParagraphHeightChanged( USHORT nPara );
 
 	// #101498#
-	virtual void	DrawingText( const Point& rStartPos, const String& rText, USHORT nTextStart, USHORT nTextLen, const long* pDXArray, const SvxFont& rFont, USHORT nPara, xub_StrLen nIndex, BYTE nRightToLeft);
+	virtual void	DrawingText( const Point& rStartPos, const String& rText, USHORT nTextStart, USHORT nTextLen, const sal_Int32* pDXArray, const SvxFont& rFont, USHORT nPara, xub_StrLen nIndex, BYTE nRightToLeft);
 
 	virtual String	GetUndoComment( USHORT nUndoId ) const;
 	virtual BOOL	FormattingParagraph( USHORT nPara );